==> allensdk-2.8.0-py3-none-any.whl: allensdk/brain_observatory/ecephys/stimulus_table/__main__.py <==
import functools
import warnings
import re

import pandas as pd
import numpy as np

from allensdk.brain_observatory.ecephys.file_io.ecephys_sync_dataset import (
    EcephysSyncDataset,
)
from allensdk.brain_observatory.argschema_utilities import ArgSchemaParserPlus
from allensdk.brain_observatory.ecephys.file_io.stim_file import (
    CamStimOnePickleStimFile,
)

from . import ephys_pre_spikes
from . import naming_utilities
from . import output_validation
from ._schemas import InputParameters, OutputSchema


def build_stimulus_table(
    stimulus_pkl_path,
    sync_h5_path,
    frame_time_strategy,
    minimum_spontaneous_activity_duration,
    extract_const_params_from_repr,
    drop_const_params,
    maximum_expected_spontanous_activity_duration,
    stimulus_name_map,
    column_name_map,
    output_stimulus_table_path,
    output_frame_times_path,
    fail_on_negative_duration,
    **kwargs
):

    stim_file = CamStimOnePickleStimFile.factory(stimulus_pkl_path)

    sync_dataset = EcephysSyncDataset.factory(sync_h5_path)
    frame_times = sync_dataset.extract_frame_times(strategy=frame_time_strategy)

    seconds_to_frames = (
        lambda seconds: (np.array(seconds) + stim_file.pre_blank_sec)
        * stim_file.frames_per_second
    )
    minimum_spontaneous_activity_duration = (
        minimum_spontaneous_activity_duration / stim_file.frames_per_second
    )

    stimulus_tabler = functools.partial(
        ephys_pre_spikes.build_stimuluswise_table,
        seconds_to_frames=seconds_to_frames,
        extract_const_params_from_repr=extract_const_params_from_repr,
        drop_const_params=drop_const_params,
    )
    spon_tabler = functools.partial(
        ephys_pre_spikes.make_spontaneous_activity_tables,
        duration_threshold=minimum_spontaneous_activity_duration,
    )

    stim_table_full = ephys_pre_spikes.create_stim_table(
        stim_file.stimuli, stimulus_tabler, spon_tabler
    )
    stim_table_full = ephys_pre_spikes.apply_frame_times(
        stim_table_full, frame_times, stim_file.frames_per_second, True
    )

    output_validation.validate_epoch_durations(stim_table_full, fail_on_negative_durations=fail_on_negative_duration)
    output_validation.validate_max_spontaneous_epoch_duration(
        stim_table_full, maximum_expected_spontanous_activity_duration
    )

    stim_table_full = naming_utilities.collapse_columns(stim_table_full)
    stim_table_full = naming_utilities.drop_empty_columns(stim_table_full)
    stim_table_full = naming_utilities.standardize_movie_numbers(stim_table_full)
    stim_table_full = naming_utilities.add_number_to_shuffled_movie(stim_table_full)
    stim_table_full = naming_utilities.map_stimulus_names(
        stim_table_full, stimulus_name_map
    )
    stim_table_full = naming_utilities.map_column_names(stim_table_full, column_name_map)

    stim_table_full.to_csv(output_stimulus_table_path, index=False)
    np.save(output_frame_times_path, frame_times, allow_pickle=False)
    return {
        "output_path": output_stimulus_table_path,
        "output_frame_times_path": output_frame_times_path,
    }


def main():

    mod = ArgSchemaParserPlus(
        schema_type=InputParameters, output_schema_type=OutputSchema
    )
    output = build_stimulus_table(**mod.args)

    output.update({"input_parameters": mod.args})
    if "output_json" in mod.args:
        mod.output(output, indent=2)
    else:
        print(mod.get_output_json(output))


if __name__ == "__main__":
    main()

==> allensdk-2.12.4-py3-none-any.whl: allensdk/brain_observatory/ecephys/stimulus_table/__main__.py <==
import functools

import numpy as np

from allensdk.brain_observatory.argschema_utilities import \
    ArgSchemaParserPlus, \
    write_or_print_outputs
from allensdk.brain_observatory.ecephys.file_io.ecephys_sync_dataset import (
    EcephysSyncDataset,
)
from allensdk.brain_observatory.ecephys.file_io.stim_file import (
    CamStimOnePickleStimFile,
)
from . import ephys_pre_spikes
from . import naming_utilities
from . import output_validation
from ._schemas import InputParameters, OutputSchema


def build_stimulus_table(
        stimulus_pkl_path,
        sync_h5_path,
        frame_time_strategy,
        minimum_spontaneous_activity_duration,
        extract_const_params_from_repr,
        drop_const_params,
        maximum_expected_spontanous_activity_duration,
        stimulus_name_map,
        column_name_map,
        output_stimulus_table_path,
        output_frame_times_path,
        fail_on_negative_duration,
        **kwargs
):
    stim_file = CamStimOnePickleStimFile.factory(stimulus_pkl_path)

    sync_dataset = EcephysSyncDataset.factory(sync_h5_path)
    frame_times = sync_dataset.extract_frame_times(
        strategy=frame_time_strategy)

    def seconds_to_frames(seconds):
        return  \
            (np.array(seconds) + stim_file.pre_blank_sec) * \
            stim_file.frames_per_second

    minimum_spontaneous_activity_duration = (
            minimum_spontaneous_activity_duration / stim_file.frames_per_second
    )

    stimulus_tabler = functools.partial(
        ephys_pre_spikes.build_stimuluswise_table,
        seconds_to_frames=seconds_to_frames,
        extract_const_params_from_repr=extract_const_params_from_repr,
        drop_const_params=drop_const_params,
    )
    spon_tabler = functools.partial(
        ephys_pre_spikes.make_spontaneous_activity_tables,
        duration_threshold=minimum_spontaneous_activity_duration,
    )

    stim_table_full = ephys_pre_spikes.create_stim_table(
        stim_file.stimuli, stimulus_tabler, spon_tabler
    )
    stim_table_full = ephys_pre_spikes.apply_frame_times(
        stim_table_full, frame_times, stim_file.frames_per_second, True
    )

    output_validation.validate_epoch_durations(
        stim_table_full, fail_on_negative_durations=fail_on_negative_duration)
    output_validation.validate_max_spontaneous_epoch_duration(
        stim_table_full, maximum_expected_spontanous_activity_duration
    )

    stim_table_full = naming_utilities.collapse_columns(stim_table_full)
    stim_table_full = naming_utilities.drop_empty_columns(stim_table_full)
    stim_table_full = naming_utilities.standardize_movie_numbers(
        stim_table_full)
    stim_table_full = naming_utilities.add_number_to_shuffled_movie(
        stim_table_full)
    stim_table_full = naming_utilities.map_stimulus_names(
        stim_table_full, stimulus_name_map
    )
    stim_table_full = naming_utilities.map_column_names(stim_table_full,
                                                        column_name_map)

    stim_table_full.to_csv(output_stimulus_table_path, index=False)
    np.save(output_frame_times_path, frame_times, allow_pickle=False)
    return {
        "output_path": output_stimulus_table_path,
        "output_frame_times_path": output_frame_times_path,
    }


def main():
    mod = ArgSchemaParserPlus(
        schema_type=InputParameters, output_schema_type=OutputSchema
    )
    output = build_stimulus_table(**mod.args)

    write_or_print_outputs(data=output, parser=mod)


if __name__ == "__main__":
    main()
